==> typolight-2.6.2.tar.gz: typolight-2.6.2/system/modules/rep_base/languages/de/tl_repository.php <==
<?php
/**
 * TL_ROOT/system/modules/rep_base/languages/de/tl_repository.php 
 * 
 * TYPOlight extension: rep_base 1.0.0 rc1 
 * German translation file 
 * 
 * Copyright : (c)  2008 IBK Software AG 
 * License   : GNU LGPL V3 
 * Author    : Peter Koch (acenes), http://contifex.com 
 * Translator: Peter Koch (acenes), http://contifex.com 
 */

/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_repository']['category']      = array('Kategorie', 'Bitte wählen Sie die Erweiterungs-Kategorie.');
$GLOBALS['TL_LANG']['tl_repository']['copyright']     = array('Urheberrecht', 'Hier können Sie einen Urheberrecht-Vermerk eingeben (z.B. &amp;copy; 2007,2008 ACME Holding Inc).');
$GLOBALS['TL_LANG']['tl_repository']['demo']          = array('Demo vorhanden', 'Die kommerzielle Erweiterung kann auch ohne Schlüssel als Demoversion installiert werden.');
$GLOBALS['TL_LANG']['tl_repository']['description']   = array('Beschreibung', 'Folgende HTML-Tags sind erlaubt: %s');
$GLOBALS['TL_LANG']['tl_repository']['extension']     = array('Erweiterung', 'Bitte wählen Sie den Namen der Erweiterung.');
$GLOBALS['TL_LANG']['tl_repository']['functionality'] = array('Funktion', 'Bietet die Erweiterung die erwarteten Funktionen?');
$GLOBALS['TL_LANG']['tl_repository']['license']       = array('Lizenz', 'Eingabe einer kurzen Lizenzinformation für freie Erweiterungen. Ausführliche Lizenzinformationen können z.B. in einer Datei LICENSE.txt hinterlegt werden.');
$GLOBALS['TL_LANG']['tl_repository']['name']          = array('Name', 'Erweiterungsnamen müssen mit a-z, A-Z oder 0-9 beginnen, wobei bevorzugt die Kleinschreibung anzuwenden ist. Innerhalb des Namens sind zusätzlich die Zeichen _ und - erlaubt.');
$GLOBALS['TL_LANG']['tl_repository']['popularity']    = array('Popularität', '%s/%s (Downloads/Install.)');
$GLOBALS['TL_LANG']['tl_repository']['quality']       = array('Qualität', 'Wie robust ist die Erweiterung und wie einfach und logisch gestalten sich Installation und Unterhalt?');
$GLOBALS['TL_LANG']['tl_repository']['releasedate']   = array('Freigabedatum', 'Eingabe des Veröffentlichungs-Datums dieser Freigabe im Format JJJJ-MM-TT.');
$GLOBALS['TL_LANG']['tl_repository']['selversion']    = array('Version', 'Bitte wählen Sie die Version.');
$GLOBALS['TL_LANG']['tl_repository']['type']          = array('Typ', 'Bitte wählen Sie den Erweiterung-Typ.');
$GLOBALS['TL_LANG']['tl_repository']['usability']     = array('Bedienung', 'Werden die TYPOlight-Standards zur Bedienung und zur Zugänglichkeit eingehalten?');
$GLOBALS['TL_LANG']['tl_repository']['version']       = array('Version', 'Versionsnummern müssen im Format n.n.n s sein, wobei n ganze Zahlen sind und s eines der folgenden Texte ist: alpha1, alpha2, alpha3, beta1, beta2, beta3, rc1, rc2, rc3, stable');

/**
 * References
 */
$GLOBALS['TL_LANG']['tl_repository']['author']            = 'Autor';
$GLOBALS['TL_LANG']['tl_repository']['build']             = 'Build';
$GLOBALS['TL_LANG']['tl_repository']['cancel']            = 'Abbruch';
$GLOBALS['TL_LANG']['tl_repository']['continue']          = 'Weiter';
$GLOBALS['TL_LANG']['tl_repository']['dependencies']      = 'Abhängigkeiten dieser Erweiterung';
$GLOBALS['TL_LANG']['tl_repository']['dependents']        = 'Von dieser abhängige andere Erweiterungen';
$GLOBALS['TL_LANG']['tl_repository']['dependentsdel']     = 'Folgende Erweiterungen sind von <em>%s</em> abhängig und könnten unbrauchbar werden:';
$GLOBALS['TL_LANG']['tl_repository']['donate']            = 'Spenden';
$GLOBALS['TL_LANG']['tl_repository']['downloads']         = 'Paket-Downloads';
$GLOBALS['TL_LANG']['tl_repository']['extensionnotfound'] = 'Erweiterung nicht gefunden.';
$GLOBALS['TL_LANG']['tl_repository']['forum']             = 'Forum';
$GLOBALS['TL_LANG']['tl_repository']['installs']          = 'Online-Installationen';
$GLOBALS['TL_LANG']['tl_repository']['langtrans']         = '%s übers.';
$GLOBALS['TL_LANG']['tl_repository']['manual']            = 'Handbuch';
$GLOBALS['TL_LANG']['tl_repository']['no']                = 'nein';
$GLOBALS['TL_LANG']['tl_repository']['noextensionsfound'] = 'Keine Erweiterungen gefunden.';
$GLOBALS['TL_LANG']['tl_repository']['orderby']           = 'Sortieren nach';
$GLOBALS['TL_LANG']['tl_repository']['otherlanguages']    = 'Andere Sprachen';
$GLOBALS['TL_LANG']['tl_repository']['pageof']            = 'Seite %s von %s';
$GLOBALS['TL_LANG']['tl_repository']['ratingfmt']         = '%.2f (%d Stimmen)';
$GLOBALS['TL_LANG']['tl_repository']['reldownloads']      = 'Version Downloads';
$GLOBALS['TL_LANG']['tl_repository']['releasenotesfor']   = 'Freigabe-Notizen und Änderungs-Log für %s';
$GLOBALS['TL_LANG']['tl_repository']['relfunctionality']  = 'Version Funktion';
$GLOBALS['TL_LANG']['tl_repository']['relinstalls']       = 'Version Install.';
$GLOBALS['TL_LANG']['tl_repository']['relquality']        = 'Version Qualität';
$GLOBALS['TL_LANG']['tl_repository']['relrating']         = 'Version Wertung';
$GLOBALS['TL_LANG']['tl_repository']['relupdates']        = 'Version Updates';
$GLOBALS['TL_LANG']['tl_repository']['relusability']      = 'Version Bedienung';
$GLOBALS['TL_LANG']['tl_repository']['save']              = 'Speichern';
$GLOBALS['TL_LANG']['tl_repository']['shop']              = 'Shop';
$GLOBALS['TL_LANG']['tl_repository']['showpicture']       = 'Bild in voller Grösse anzeigen';
$GLOBALS['TL_LANG']['tl_repository']['state']             = 'Status';
$GLOBALS['TL_LANG']['tl_repository']['tag']               = 'Suchbegriff';
$GLOBALS['TL_LANG']['tl_repository']['thumbnail']         = 'Miniaturbild';
$GLOBALS['TL_LANG']['tl_repository']['totdownloads']      = 'Total Downloads';
$GLOBALS['TL_LANG']['tl_repository']['totfunctionality']  = 'Total Funktion';
$GLOBALS['TL_LANG']['tl_repository']['totinstalls']       = 'Total Install.';
$GLOBALS['TL_LANG']['tl_repository']['totquality']        = 'Total Qualität';
$GLOBALS['TL_LANG']['tl_repository']['totrating']         = 'Total Wertung';
$GLOBALS['TL_LANG']['tl_repository']['totupdates']        = 'Total Updates';
$GLOBALS['TL_LANG']['tl_repository']['totusability']      = 'Total Bedienung';
$GLOBALS['TL_LANG']['tl_repository']['versionfrom']       = 'Version von';
$GLOBALS['TL_LANG']['tl_repository']['versions']          = 'Andere Versionen';
$GLOBALS['TL_LANG']['tl_repository']['versionto']         = 'Version bis';
$GLOBALS['TL_LANG']['tl_repository']['yes']               = 'ja';

/**
 * Types
 */
$GLOBALS['TL_LANG']['tl_repository']['type_options']['free']       = 'Frei';
$GLOBALS['TL_LANG']['tl_repository']['type_options']['private']    = 'Privat';
$GLOBALS['TL_LANG']['tl_repository']['type_options']['commercial'] = 'Kommerziell';

/**
 * Categories
 */
$GLOBALS['TL_LANG']['tl_repository']['category_options']['application'] = 'Anwendung';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['utility']     = 'Hilfsprogramm';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['template']    = 'Vorlage';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['widget']      = 'Widget';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['plugin']      = 'Plugin';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['other']       = 'Andere';
$GLOBALS['TL_LANG']['tl_repository']['category_options']['core']        = 'Core';

/**
 * Sorting
 */
$GLOBALS['TL_LANG']['tl_repository']['order_options']['reldate'] = 'Freigabedatum';
$GLOBALS['TL_LANG']['tl_repository']['order_options']['rating']  = 'Wertung';
$GLOBALS['TL_LANG']['tl_repository']['order_options']['popular'] = 'Popularität';
$GLOBALS['TL_LANG']['tl_repository']['order_options']['name']    = 'Name';
$GLOBALS['TL_LANG']['tl_repository']['order_options']['title']   = 'Titel';
$GLOBALS['TL_LANG']['tl_repository']['order_options']['author']  = 'Autor';

/**
 * States
 */
$GLOBALS['TL_LANG']['tl_repository']['state_options']['alpha']   = 'Alfa';
$GLOBALS['TL_LANG']['tl_repository']['state_options']['beta']    = 'Beta';
$GLOBALS['TL_LANG']['tl_repository']['state_options']['rc']      = 'RC';
$GLOBALS['TL_LANG']['tl_repository']['state_options']['stable']  = 'Stabil';
 
?>

==> typolight-2.6.7.tar.gz: typolight-2.6.7/system/modules/rep_base/languages/de/tl_repository.php <==
<?php
/**
 * TL_ROOT/system/modules/rep_base/languages/de/tl_repository.php 
 * 
 * TYPOlight extension: rep_base 1.0.0 rc1 
 * German translation file 
 * 
 * Copyright : (c)  2008 IBK Software AG 
 * License   : GNU LGPL V3 
 * Author    : Peter Koch (acenes), http://contifex.com 
 * Translator: Peter Koch (acenes), http://contifex.com 
 */

/**
 * Fields
 */
$GLOBALS['TL_LANG']['tl_repository']['category']      = array('Kategorie', 'Bitte wählen Sie die Erweiterungs-Kategorie.');
$GLOBALS['TL_LANG']['tl_repository']['copyright']     = array('Urheberrecht', 'Hier können Sie einen Urheberrecht-Vermerk eingeben (z.B. &amp;copy; 2007,2008 ACME Holding Inc).');
$GLOBALS['TL_LANG']['tl_repository']['demo']          = array('Demo vorhanden', 'Die kommerzielle Erweiterung kann auch ohne Schlüssel als Demoversion installiert werden.');
$GLOBALS['TL_LANG']['tl_repository']['description']   = array('Beschreibung', 'Folgende HTML-Tags sind erlaubt: %s');
$GLOBALS['TL_LANG']['tl_repository']['extension']     = array('Erweiterung', 'Bitte wählen Sie den Namen der Erweiterung.');
$GLOBALS['TL_LANG']['tl_repository']['functionality'] = array('Funktion', 'Bietet die Erweiterung die erwarteten Funktionen?');
$GLOBALS['TL_LANG']['tl_repository']['license']       = array('Lizenz', 'Eingabe einer kurzen Lizenzinformation für freie Erweiterungen. Ausführliche Lizenzinformationen können z.B. in einer Datei LICENSE.txt hinterlegt werden.');
$GLOBALS['TL_LANG']['tl_repository']['name']          = array('Name', 'Erweiterungsnamen müssen mit a-z, A-Z oder 0-9 beginnen, wobei bevorzugt die Kleinschreibung anzuwenden ist. Innerhalb des Namens sind zusätzlich die Zeichen _ und - erlaubt.');
$GLOBALS['TL_LANG']['tl_repository']['popularity']    = array('Popularität', '%s/%s (Downloads/Install.)');
$GLOBALS['TL_LANG']['tl_repository']['quality']       = array('Qualität', 'Wie robust ist die Erweiterung und wie einfach und logisch gestalten sich Installation und Unterhalt?');
$GLOBALS['TL_LANG']['tl_repository']['releasedate']   = array('Freigabedatum', 'Eingabe des Veröffentlichungs-Datums dieser Freigabe im Format JJJJ-MM-TT.');
$GLOBALS['TL_LANG']['tl_repository']['selversion']    = array('Version', 'Bitte wählen Sie die Version.');
$GLOBALS['TL_LANG']['tl_repository']['type']          = array('Typ', 'Bitte wählen Sie den Erweiterung-Typ.');
$GLOBALS['TL_LANG']['tl_repository']['usability']     = array('Bedienung', 'Werden die TYPOlight-Standards zur Bedienung und zur Zugänglichkeit eingehalten?');
$GLOBALS['TL_LANG']['tl_repository']['version']       = array('Version', 'Versionsnummern müssen im Format n.n.n s sein, wobei n ganze Zahlen sind und s eines der folgenden Texte ist: alpha1, alpha2, alpha3, beta1, beta2, beta3, rc1, rc2, rc3, stable');

/**
 * References
 */
$GLOBALS['TL_LANG']['tl_repository']['author']            = 'Autor';
$GLOBALS['TL_LANG']['tl_repository']['build']             = 'Build';
$GLOBALS['TL_LANG']['tl_repository']['cancel']            = 'Abbruch';
$GLOBALS['TL_LANG']['tl_repository']['continue']          = 'Weiter';
$GLOBALS['TL_LANG']['tl_repository']['dependencies']      = 'Abhängigkeiten dieser Erweiterung';
$GLOBALS['TL_LANG']['tl_repository']['dependents']        = 'Von dieser abhängige andere Erweiterungen';
$GLOBALS['TL_LANG']['tl_repository']['dependentsdel']     = 'Folgende Erweiterungen sind von <em>%s</em> abhängig und könnten unbrauchbar werden:';
$GLOBALS['TL_LANG']['tl_repository']['donate']            = 'Spenden';
$GLOBALS['TL_LANG']['tl_repository']['downloads']         = 'Paket-Downloads';
$GLOBALS['TL_LANG']['tl_repository']['extensionnotfound'] = 'Erweiterung nicht gefunden.';
$GLOBALS['TL_LANG']['tl_repository']['forum']             = 'Forum';
$GLOBALS['TL_LANG']['tl_repository']['installs']          = 'Online-Installationen';
$GLOBALS['TL_LANG']['tl_repository']['langtrans']         = '%s übers.';
$GLOBALS['TL_LANG']['tl_repository']['manual']            = 'Handbuch';
$GLOBALS['TL_LANG']['tl_repository']['no']                = 'nein';
$GLOBALS['TL_LANG']['tl_repository']['noextensionsfound'] = 'Keine Erweiterungen gefunden.';
$GLOBALS['TL_LANG']['tl_repository']['orderby']           = 'Sortieren nach';
$GLOBALS['TL_LANG']['tl_repository']['otherlanguages']    = 'Andere Sprachen';
$GLOBALS['TL_LANG']['tl_repository']['pageof']            = 'Seite %s von %s';
$GLOBALS['TL_LANG']['tl_repository']['ratingfmt']         = '%.2f (%d Stimmen)';
$GLOBALS['TL_LANG']['tl_repository']['reldownloads']      = 'Version Downloads';
$GLOBALS['TL_LANG']['tl_repository']['releasenotesfor']   = 'Freigabe-Notizen und Änderungs-Log für %s';
$GLOBALS['TL_LANG']['tl_repository']['relfunctionality']  = 'Version Funktion';
$GLOBALS['TL_LANG']['tl_repository']['relinstalls']       = 'Version Install.';
$GLOBALS['TL_LANG']['tl_repository']['relquality']        = 'Version Qualität';
$GLOBALS['TL_LANG']['tl_repository']['relrating']         = 'Version Wertung';
$GLOBALS['TL_LANG']['tl_repository']['relupdates']        = 'Version Updates';
$GLOBALS['TL_LANG']['tl_repository']['relusability']      = 'Version Bedienung';
$GLOBALS['TL_LANG']['tl_repository']['save']              = 'Speichern';
$GLOBALS['TL_LANG']['tl_repository']['shop']              = 'Shop';
$GLOBALS['TL_LANG']['tl_repository']['showpicture']       = 'Bild in voller Grösse anzeigen';
$GLOBALS['TL_LANG']['tl_repository']['state']             = 'Status';
$GLOBALS['TL_LANG']['tl_repository']['tag']               = 'Suchbegriff';
$GLOBALS['TL_LANG']['tl_repository']['thumbnail']         = 'Miniaturbild';
$GLOBALS['TL_LANG']['tl_repository']['totdownloads']      = 'Total Downloads';
$GLOBALS['TL_LANG']['tl_repository']['totfunctionality']  = 'Total Funktion';
$GLOBALS['TL_LANG']['tl_repository']['totinstalls']       = 'Total Install.';
$GLOBALS['TL_LANG']['tl_repository']['totquality']        = 'Total Qualität';
$GLOBALS['TL_LANG']['tl_repository']['totrating']         = 'Total Wertung';
$GLOBALS['TL_LANG']['tl_repository']['totupdates']        = 'Total Updates';
$GLOBALS['TL_LANG']['tl_repository']['totusability']      = 'Total Bedienung';
$GLOBALS['TL_LANG']['tl_repository']['versionfrom']       = 'Version von';
$GLOBALS['TL_LANG']['tl_repository']['versions']          = 'Andere Versionen';
$GLOBALS['TL_LANG']['tl_repository']['versionto']         = 'Version bis';
$GLOBALS['TL_LANG']['tl_repository']['yes']               = 'ja';

/**
 * Types
 */
$GLOBALS['TL_LANG']['tl_repository_type_options']['free']       = 'Frei';
$GLOBALS['TL_LANG']['tl_repository_type_options']['private']    = 'Privat';
$GLOBALS['TL_LANG']['tl_repository_type_options']['commercial'] = 'Kommerziell';

/**
 * Categories
 */
$GLOBALS['TL_LANG']['tl_repository_category_options']['application'] = 'Anwendung';
$GLOBALS['TL_LANG']['tl_repository_category_options']['utility']     = 'Hilfsprogramm';
$GLOBALS['TL_LANG']['tl_repository_category_options']['template']    = 'Vorlage';
$GLOBALS['TL_LANG']['tl_repository_category_options']['widget']      = 'Widget';
$GLOBALS['TL_LANG']['tl_repository_category_options']['plugin']      = 'Plugin';
$GLOBALS['TL_LANG']['tl_repository_category_options']['other']       = 'Andere';
$GLOBALS['TL_LANG']['tl_repository_category_options']['core']        = 'Core';

/**
 * Sorting
 */
$GLOBALS['TL_LANG']['tl_repository_order_options']['reldate'] = 'Freigabedatum';
$GLOBALS['TL_LANG']['tl_repository_order_options']['rating']  = 'Wertung';
$GLOBALS['TL_LANG']['tl_repository_order_options']['popular'] = 'Popularität';
$GLOBALS['TL_LANG']['tl_repository_order_options']['name']    = 'Name';
$GLOBALS['TL_LANG']['tl_repository_order_options']['title']   = 'Titel';
$GLOBALS['TL_LANG']['tl_repository_order_options']['author']  = 'Autor';

/**
 * States
 */
$GLOBALS['TL_LANG']['tl_repository_state_options']['alpha']   = 'Alpha';
$GLOBALS['TL_LANG']['tl_repository_state_options']['beta']    = 'Beta';
$GLOBALS['TL_LANG']['tl_repository_state_options']['rc']      = 'RC';
$GLOBALS['TL_LANG']['tl_repository_state_options']['stable']  = 'Stabil';
 
?>
